@@ -1,8 +1,6 @@
-/* $Id: demowindow.cc,v 1.44 2002/10/22 22:33:05 daniel Exp $ */
+/* $Id: demowindow.cc,v 1.47 2004/03/14 14:48:12 murrayc Exp $ */
 
-/* demowindow.cc
- *
- * Copyright (C) 2001 The gtkmm Development Team
+/* Copyright (C) 2001 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -33,6 +31,17 @@
 #include <cctype>
 #include <cerrno>
 
+//The SUN Forte compiler can't seem to either find the declarations or the implementations,
+//so these are not used on that platform.
+//#include <stdio.h> //Needed by the SUN Forte compiler, for flockfile().
+//SUN Forte seems to need these:
+//void flockfile(FILE*);
+//void funlockfile(FILE*);
+#ifdef GLIBMM_COMPILER_SUN_FORTE
+  //These don't wotk even though the configure-time check works.
+  #undef HAVE_FLOCKFILE
+  #undef HAVE_FUNLOCKFILE
+#endif
 
 namespace
 {
@@ -73,6 +82,7 @@ DemoWindow::DemoWindow()
 
   m_refTreeSelection = m_TreeView.get_selection();
   m_refTreeSelection->set_mode(Gtk::SELECTION_BROWSE);
+  m_refTreeSelection->set_select_function(&DemoWindow::select_function);
 
   m_TreeView.set_size_request(200, -1);
 
@@ -162,6 +172,14 @@ void DemoWindow::on_treeview_row_activated(const Gtk::TreePath& path, Gtk::TreeV
   }
 }
 
+// static
+bool DemoWindow::select_function(const Glib::RefPtr<Gtk::TreeModel>& model,
+                                 const Gtk::TreePath& path, bool)
+{
+  const Gtk::TreeModel::iterator iter = model->get_iter(path);
+  return iter->children().empty(); // only allow leaf nodes to be selected
+}
+
 void DemoWindow::on_treeselection_changed()
 {
   if(const Gtk::TreeIter iter = m_refTreeSelection->get_selected())
@@ -171,7 +189,6 @@ void DemoWindow::on_treeselection_changed()
   }
 }
 
-
 bool DemoWindow::read_line (FILE *stream, GString *str)
 {
   int n_read = 0;
@@ -289,7 +306,8 @@ void DemoWindow::load_file(const std::string& filename)
     	    {
     	      Gtk::TextIter end = start;
 
-    	      g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
+    	      // The SUN Forte compiler says this is a badly formed expression.
+              //g_assert (int(strlen(p)) >= (q - p)); //TODO: What is this for?  daniel.
 
               const Glib::ustring strTemp (p, q);
     	      end = refBufferInfo->insert(end, strTemp);
@@ -332,7 +350,8 @@ void DemoWindow::load_file(const std::string& filename)
                       start = refBufferInfo->insert(start, " ");
                     }
 
-                  g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
+                  // The SUN Forte compiler says this is a badly formed expression.
+                  // g_assert (int(strlen(p)) >= len); //TODO: What is this for?  daniel.
 
                   start = refBufferInfo->insert(start, Glib::ustring(p, p + len));
                   in_para = 1;
