@@ -13,8 +13,6 @@
  */
 
 #include <gtkmm.h>
-#include <stdio.h>
-#include <errno.h>
 
 class Example_Images : public Gtk::Window
 {
@@ -23,7 +21,7 @@ public:
   virtual ~Example_Images();
 
 protected:
-  virtual void start_progressive_loading(Gtk::Image& image);
+  virtual void start_progressive_loading();
 
   //signal handler:
   virtual bool on_timeout();
@@ -38,8 +36,7 @@ protected:
   Gtk::Image m_Image_Progressive;
   Glib::RefPtr<Gdk::PixbufLoader> m_refPixbufLoader;
 
-  SigC::Connection m_TimeoutConnection;
-  FILE* m_image_stream;
+  Glib::RefPtr<Glib::IOChannel> m_image_stream;
 };
 
 //Called by DemoWindow;
@@ -49,23 +46,22 @@ Gtk::Window* do_images()
 }
 
 Example_Images::Example_Images()
-: m_VBox(false, 8),
-  m_Alignment_Image(0.5, 0.5, 0, 0),
-  m_Alignment_Animation(0.5, 0.5, 0, 0)
+:
+  m_VBox                (false, 8),
+  m_Alignment_Image     (0.5, 0.5, 0, 0),
+  m_Alignment_Animation (0.5, 0.5, 0, 0),
+  m_image_stream        (0)
 {
-  m_image_stream = 0;
-
   set_title("Images");
   set_border_width(8);
 
   m_VBox.set_border_width(8);
   add(m_VBox);
 
-
   /* Image */
 
   m_Label_Image.set_markup("<u>Image loaded from a file</u>");
-  m_VBox.pack_start(m_Label_Image, Gtk::SHRINK);
+  m_VBox.pack_start(m_Label_Image, Gtk::PACK_SHRINK);
 
   m_Frame_Image.set_shadow_type(Gtk::SHADOW_IN);
 
@@ -73,33 +69,31 @@ Example_Images::Example_Images()
    * the window
    */
   m_Alignment_Image.add(m_Frame_Image);
-  m_VBox.pack_start(m_Alignment_Image, Gtk::SHRINK);
+  m_VBox.pack_start(m_Alignment_Image, Gtk::PACK_SHRINK);
 
-  Gtk::Image* pImage = Gtk::manage( new Gtk::Image(Glib::ustring("./gtk-logo-rgb.gif")) );		
+  Gtk::Image* pImage = Gtk::manage(new Gtk::Image("gtk-logo-rgb.gif"));
   m_Frame_Image.add(*pImage);
 
-
   /* Animation */
 
   m_Label_Animation.set_markup("<u>Animation loaded from a file</u>");
-  m_VBox.pack_start(m_Label_Animation, Gtk::SHRINK);
+  m_VBox.pack_start(m_Label_Animation, Gtk::PACK_SHRINK);
 
   m_Frame_Animation.set_shadow_type(Gtk::SHADOW_IN);
 
   /* The alignment keeps the frame from growing when users resize
-  * the window
-  */
+   * the window
+   */
   m_Alignment_Animation.add(m_Frame_Animation);
-  m_VBox.pack_start(m_Alignment_Animation, Gtk::SHRINK);
+  m_VBox.pack_start(m_Alignment_Animation, Gtk::PACK_SHRINK);
 
-  pImage = Gtk::manage( new Gtk::Image(Glib::ustring("./floppybuddy.gif")) );		
+  pImage = Gtk::manage(new Gtk::Image("floppybuddy.gif"));
   m_Frame_Animation.add(*pImage);
 
-
   /* Progressive */
 
   m_Label_Progressive.set_markup("<u>Progressive image loading</u>");
-  m_VBox.pack_start(m_Label_Progressive, Gtk::SHRINK);
+  m_VBox.pack_start(m_Label_Progressive, Gtk::PACK_SHRINK);
 
   m_Frame_Progressive.set_shadow_type(Gtk::SHADOW_IN);
 
@@ -107,26 +101,34 @@ Example_Images::Example_Images()
   * the window
   */
   m_Alignment_Progressive.add(m_Frame_Progressive);
-  m_VBox.pack_start(m_Alignment_Progressive, Gtk::SHRINK);
+  m_VBox.pack_start(m_Alignment_Progressive, Gtk::PACK_SHRINK);
 
   /* Create an empty image for now; the progressive loader
    * will create the pixbuf and fill it in.
    */
   m_Frame_Progressive.add(m_Image_Progressive);
 
-  start_progressive_loading(m_Image_Progressive);
+  start_progressive_loading();
 
   show_all();
 }
 
 Example_Images::~Example_Images()
 {
+  try
+  {
+    if(m_refPixbufLoader)
+      m_refPixbufLoader->close();
+  }
+  catch(const Gdk::PixbufError&)
+  {
+    // ignore errors
+  }
 }
 
-void Example_Images::start_progressive_loading(Gtk::Image& image)
+void Example_Images::start_progressive_loading()
 {
-  m_TimeoutConnection = Gtk::Main::signal_timeout().connect(
-      SigC::slot(*this, &Example_Images::on_timeout), 150);
+  Glib::signal_timeout().connect(SigC::slot(*this, &Example_Images::on_timeout), 150);
 }
 
 bool Example_Images::on_timeout()
@@ -136,106 +138,114 @@ bool Example_Images::on_timeout()
    * function to make things nicer.
    */
 
-  if (m_image_stream)
+  if(m_image_stream)
   {
-    guchar buf[256];
-    GError* error = NULL;
+    guint8 buf[256];
+    gsize bytes_read = 0;
+    Glib::IOStatus status = Glib::IO_STATUS_NORMAL;
 
-    size_t bytes_read = fread (buf, 1, 256, m_image_stream);
-
-    if (ferror (m_image_stream))
-  	{
+    try
+    {
+      status = m_image_stream->read(reinterpret_cast<char*>(&buf[0]), sizeof(buf), bytes_read);
+    }
+    catch(const Glib::Error& error)
+    {
       Glib::ustring strMsg = "Failure reading image file 'alphatest.png': ";
-      strMsg += g_strerror (errno);
+      strMsg += error.what();
 
-      Gtk::MessageDialog dialog(strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
+      Gtk::MessageDialog dialog (strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
       dialog.run();
 
-  	  fclose (m_image_stream);
-  	  m_image_stream = NULL;
-    	
-  	  m_TimeoutConnection.disconnect();
+      m_image_stream.clear();
 
-  	  return false; /* uninstall the timeout */
-  	}
+      return false; // uninstall the timeout
+    }
 
-    if (!m_refPixbufLoader->write(buf, bytes_read, error))
-  	{
+    try
+    {
+      m_refPixbufLoader->write(buf, bytes_read);
+    }
+    catch(const Glib::Error& error)
+    {
       Glib::ustring strMsg = "Failed to load image: ";
-      strMsg += error->message;
+      strMsg += error.what();
 
-      Gtk::MessageDialog dialog(strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
+      Gtk::MessageDialog dialog (strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
       dialog.run();
 
-  	  fclose (m_image_stream);
-  	  m_image_stream = NULL;
-    	
-  	  m_TimeoutConnection.disconnect();
+      m_image_stream.clear();
 
-  	  return false; /* uninstall the timeout */
-  	}
+      return false; // uninstall the timeout
+    }
 
-    if (feof (m_image_stream))
-   	{
-   	  fclose (m_image_stream);
-   	  m_image_stream = NULL;
+    if(status == Glib::IO_STATUS_EOF)
+    {
+      m_image_stream.clear();
 
-   	  /* Errors can happen on close, e.g. if the image
-   	   * file was truncated we'll know on close that
-   	   * it was incomplete.
-   	   */
-   	  error = NULL;
-   	  if (!m_refPixbufLoader->close(error))
-   	  {
+      /* Errors can happen on close, e.g. if the image
+       * file was truncated we'll know on close that
+       * it was incomplete.
+       */
+      try
+      {
+        m_refPixbufLoader->close();
+      }
+      catch(const Glib::Error& error)
+      {
         Glib::ustring strMsg = "Failed to load image: ";
-        strMsg += error->message;
+        strMsg += error.what();
 
-        Gtk::MessageDialog dialog(strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
+        Gtk::MessageDialog dialog (strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
         dialog.run();
 
         m_refPixbufLoader.clear();
-   	    m_TimeoutConnection.disconnect();
-     	
-   	    return false; /* uninstall the timeout */
-   	  }
-	
+
+        return false; // uninstall the timeout
+      }
+
       m_refPixbufLoader.clear();
     }
   }
   else
   {
-    m_image_stream = fopen ("./alphatest.png", "r");
-    if (m_image_stream == NULL)
-  	{
-  	  Glib::ustring strMsg = "Unable to open image file 'alphatest.png': ";
-      strMsg += g_strerror (errno);
+    try
+    {
+      m_image_stream = Glib::IOChannel::create_from_file("alphatest.png", "r");
+    }
+    catch(const Glib::Error& error)
+    {
+      Glib::ustring strMsg = "Unable to open image file 'alphatest.png': ";
+      strMsg += error.what();
 
-      Gtk::MessageDialog dialog(strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
+      Gtk::MessageDialog dialog (strMsg, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_CLOSE);
       dialog.run();
 
-      m_TimeoutConnection.disconnect();
+      return false; // uninstall the timeout
+    }
 
-  	  return false; /* uninstall the timeout */
-  	}
+    m_image_stream->set_encoding(); // no encoding == binary
 
-    if (m_refPixbufLoader)
-  	{
-  	  m_refPixbufLoader->close();
-  	  m_refPixbufLoader.clear();
-  	}
+    if(m_refPixbufLoader)
+    {
+      m_refPixbufLoader->close();
+      m_refPixbufLoader.clear();
+    }
 
     m_refPixbufLoader = Gdk::PixbufLoader::create();
-    m_refPixbufLoader->signal_area_prepared().connect(SigC::slot(*this, &Example_Images::on_loader_area_prepared));
-    m_refPixbufLoader->signal_area_updated().connect(SigC::slot(*this, &Example_Images::on_loader_area_updated));
+
+    m_refPixbufLoader->signal_area_prepared().connect(
+        SigC::slot(*this, &Example_Images::on_loader_area_prepared));
+
+    m_refPixbufLoader->signal_area_updated().connect(
+        SigC::slot(*this, &Example_Images::on_loader_area_updated));
   }
 
-  /* leave timeout installed */
-  return true;
+  return true; // leave timeout installed
 }
 
 void Example_Images::on_loader_area_prepared()
 {
-  Glib::RefPtr<Gdk::Pixbuf> refPixbuf = m_refPixbufLoader->get_pixbuf();
+  const Glib::RefPtr<Gdk::Pixbuf> refPixbuf = m_refPixbufLoader->get_pixbuf();
 
   /* Avoid displaying random memory contents, since the pixbuf
    * isn't filled in yet.
@@ -244,18 +254,15 @@ void Example_Images::on_loader_area_prepared()
   m_Image_Progressive.set(refPixbuf);
 }
 
-void Example_Images::on_loader_area_updated(int x, int y, int width, int height)
+void Example_Images::on_loader_area_updated(int/*x*/, int/*y*/, int/*width*/, int/*height*/)
 {
-  /* We know the pixbuf inside the GtkImage has changed, but the image
+  /* We know the pixbuf inside the Gtk::Image has changed, but the image
    * itself doesn't know this; so queue a redraw.  If we wanted to be
    * really efficient, we could use a drawing area or something
    * instead of a GtkImage, so we could control the exact position of
    * the pixbuf on the display, then we could queue a draw for only
    * the updated area of the image.
    */
-
   m_Image_Progressive.queue_draw();
 }
 
-
-
