@@ -30,8 +30,6 @@ protected:
   //signal handlers:
   virtual void on_button_add_clicked();
   virtual void on_button_remove_clicked();
-  virtual void on_cell_edited_number(const Glib::ustring& path_string, const Glib::ustring& new_text);
-  virtual void on_cell_edited_product(const Glib::ustring& path_string, const Glib::ustring& new_text);
 
   virtual void create_model();
   virtual void add_columns();
@@ -187,8 +185,9 @@ void Example_TreeView_EditableCells::liststore_add_item(const CellItem_Product&
 
 void Example_TreeView_EditableCells::add_columns()
 {
+
   /* number column */
- m_TreeView.append_column_editable("Number", m_columns.number);
+  m_TreeView.append_column_editable("Number", m_columns.number);
 
   /* product column */
   m_TreeView.append_column_editable("Product", m_columns.product);
@@ -211,53 +210,14 @@ void Example_TreeView_EditableCells::on_button_remove_clicked()
 
   if(const Gtk::TreeIter iter = refSelection->get_selected())
   {
-    const Gtk::TreePath path (m_refListStore->get_path(iter));
+    const Gtk::TreePath path (iter);
+    const unsigned int index = path.front();
 
-    const std::vector<int> indices (path.get_indices());
-    if(!indices.empty())
-    {
-      // Remove item from ListStore:
-      m_refListStore->erase(iter);
+    // Remove item from ListStore:
+    m_refListStore->erase(iter);
 
-      // Remove item from vecItems.
-      const unsigned int index = indices[0];
-      if(index < m_vecItems.size())
-        m_vecItems.erase(m_vecItems.begin() + index);
-    }
+    // Remove item from vecItems.
+    if(index < m_vecItems.size())
+      m_vecItems.erase(m_vecItems.begin() + index);
   }
 }
-
-void Example_TreeView_EditableCells::on_cell_edited_number(
-    const Glib::ustring& path_string, const Glib::ustring& new_text)
-{
-  const Gtk::TreePath path (path_string);
-
-  const std::vector<int> indices (path.get_indices());
-  if(!indices.empty())
-  {
-    const int new_number = atoi(new_text.c_str());
-
-    const int i = indices[0];
-    m_vecItems[i].m_number = new_number;
-
-    Gtk::TreeRow row = *(m_refListStore->get_iter(path));
-    row[m_columns.number] = new_number;
-  }
-}
-
-void Example_TreeView_EditableCells::on_cell_edited_product(
-    const Glib::ustring& path_string, const Glib::ustring& new_text)
-{
-  const Gtk::TreePath path (path_string);
-
-  const std::vector<int> indices (path.get_indices());
-  if(!indices.empty())
-  {
-    const int i = indices[0];
-    m_vecItems[i].m_product = new_text;
-
-    Gtk::TreeRow row = *(m_refListStore->get_iter(path));
-    row[m_columns.product] = new_text;
-  }
-}
-
