@@ -37,9 +37,6 @@ public:
   virtual ~Example_TreeView_TreeStore();
 
 protected:
-  //signal handlers:
-  virtual void on_cell_toggled(const Glib::ustring& path_string, Gtk::TreeModelColumn<bool> column);
-
   //vfunc overrides:
   virtual void on_realize();
 
@@ -329,31 +326,26 @@ void Example_TreeView_TreeStore::add_columns()
 {
   /* column for holiday names */
   {
-    Gtk::CellRendererText* pRenderer = Gtk::manage( new Gtk::CellRendererText() );
-    pRenderer->property_xalign().set_value(0.0);
-
-    int cols_count = m_TreeView.append_column("Holiday", *pRenderer);
+    int cols_count = m_TreeView.append_column("Holiday",  m_columns.holiday_name);
     Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count-1);
     if(pColumn)
     {
-      pColumn->add_attribute(pRenderer->property_text(), m_columns.holiday_name);
+      Gtk::CellRenderer* pRenderer = pColumn->get_first_cell_renderer();  
+      pRenderer->property_xalign().set_value(0.0);
 
       pColumn->set_clickable();
     }
   }
 
   /* column for Alex */
-  {
-    Gtk::CellRendererToggle* pRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
-    pRenderer->signal_toggled().connect(
-        SigC::bind( SigC::slot(*this, &Example_TreeView_TreeStore::on_cell_toggled), m_columns.alex) );
-    pRenderer->property_xalign().set_value(0.0);
-
-    int cols_count = m_TreeView.append_column("Alex", *pRenderer);
+  { 
+    int cols_count = m_TreeView.append_column_editable("Alex", m_columns.alex);
     Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count-1);
     if(pColumn)
     {
-      pColumn->add_attribute(pRenderer->property_active(), m_columns.alex);
+      Gtk::CellRendererToggle* pRenderer = static_cast<Gtk::CellRendererToggle*>(pColumn->get_first_cell_renderer());
+      pRenderer->property_xalign().set_value(0.0);
+      
       pColumn->add_attribute(pRenderer->property_visible(), m_columns.visible);
       pColumn->add_attribute(pRenderer->property_activatable(), m_columns.world);
 
@@ -365,16 +357,13 @@ void Example_TreeView_TreeStore::add_columns()
 
   /* column for Havoc */
   {
-    Gtk::CellRendererToggle* pRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
-    pRenderer->signal_toggled().connect(
-        SigC::bind( SigC::slot(*this, &Example_TreeView_TreeStore::on_cell_toggled), m_columns.havoc) );
-    pRenderer->property_xalign().set_value(0.0);
-
-    int cols_count = m_TreeView.append_column("Havoc", *pRenderer);
+    int cols_count = m_TreeView.append_column_editable("Havoc", m_columns.havoc);
     Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count-1);
     if(pColumn)
     {
-      pColumn->add_attribute(pRenderer->property_active(), m_columns.havoc);
+      Gtk::CellRendererToggle* pRenderer = static_cast<Gtk::CellRendererToggle*>(pColumn->get_first_cell_renderer());
+      pRenderer->property_xalign().set_value(0.0);
+      
       pColumn->add_attribute(pRenderer->property_visible(), m_columns.visible);
 
       pColumn->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
@@ -385,16 +374,13 @@ void Example_TreeView_TreeStore::add_columns()
 
   /* column for Tim */
   {
-    Gtk::CellRendererToggle* pRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
-    pRenderer->signal_toggled().connect(
-        SigC::bind( SigC::slot(*this, &Example_TreeView_TreeStore::on_cell_toggled), m_columns.tim) );
-    pRenderer->property_xalign().set_value(0.0);
-
-    int cols_count = m_TreeView.append_column("Tim", *pRenderer);
+    int cols_count = m_TreeView.append_column_editable("Tim", m_columns.tim);
     Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count-1);
     if(pColumn)
     {
-      pColumn->add_attribute(pRenderer->property_active(), m_columns.tim);
+      Gtk::CellRendererToggle* pRenderer = static_cast<Gtk::CellRendererToggle*>(pColumn->get_first_cell_renderer());
+      pRenderer->property_xalign().set_value(0.0);
+      
       pColumn->add_attribute(pRenderer->property_visible(), m_columns.visible);
       pColumn->add_attribute(pRenderer->property_activatable(), m_columns.world);
 
@@ -406,16 +392,13 @@ void Example_TreeView_TreeStore::add_columns()
 
   /* column for Owen */
   {
-    Gtk::CellRendererToggle* pRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
-    pRenderer->signal_toggled().connect(
-        SigC::bind( SigC::slot(*this, &Example_TreeView_TreeStore::on_cell_toggled), m_columns.owen) );
-    pRenderer->property_xalign().set_value(0.0);
-
-    int cols_count = m_TreeView.append_column("Owen", *pRenderer);
+    int cols_count = m_TreeView.append_column_editable("Owen", m_columns.owen);
     Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count-1);
     if(pColumn)
     {
-      pColumn->add_attribute(pRenderer->property_active(), m_columns.owen);
+      Gtk::CellRendererToggle* pRenderer = static_cast<Gtk::CellRendererToggle*>(pColumn->get_first_cell_renderer());
+      pRenderer->property_xalign().set_value(0.0);
+      
       pColumn->add_attribute(pRenderer->property_visible(), m_columns.visible);
 
       pColumn->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
@@ -426,16 +409,13 @@ void Example_TreeView_TreeStore::add_columns()
 
   /* column for Dave */
   {
-    Gtk::CellRendererToggle* pRenderer = Gtk::manage( new Gtk::CellRendererToggle() );
-    pRenderer->signal_toggled().connect(
-        SigC::bind( SigC::slot(*this, &Example_TreeView_TreeStore::on_cell_toggled), m_columns.dave) );
-    pRenderer->property_xalign().set_value(0.0);
-
-    int cols_count = m_TreeView.append_column("Dave", *pRenderer);
+    int cols_count = m_TreeView.append_column("Dave", m_columns.dave);
     Gtk::TreeViewColumn* pColumn = m_TreeView.get_column(cols_count-1);
     if(pColumn)
     {
-      pColumn->add_attribute(pRenderer->property_active(), m_columns.dave);
+      Gtk::CellRendererToggle* pRenderer = static_cast<Gtk::CellRendererToggle*>(pColumn->get_first_cell_renderer());
+      pRenderer->property_xalign().set_value(0.0);
+
       pColumn->add_attribute(pRenderer->property_visible(), m_columns.visible);
 
       pColumn->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED);
@@ -446,26 +426,6 @@ void Example_TreeView_TreeStore::add_columns()
 }
 
 
-
-void Example_TreeView_TreeStore::on_cell_toggled(
-    const Glib::ustring& path_string, Gtk::TreeModelColumn<bool> column)
-{
-  Gtk::TreePath path(path_string);
-  //GtkTreePath *gpath = gtk_tree_path_new_from_string (path_string.c_str());
-  //Gtk::TreePath path(gpath);
-
-  /* get toggled iter */
-  const Gtk::TreeRow row = *(m_refTreeStore->get_iter(path));
-
-  bool toggled = row[column];
-
-  /* do something with the value */
-  toggled = !toggled;
-
-  /* set new value */
-  row[column] = toggled;
-}
-
 void Example_TreeView_TreeStore::on_realize()
 {
   m_TreeView.expand_all();
