@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.1 2002/07/13 19:03:00 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc,v 1.4 2003/09/04 16:08:35 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -17,10 +17,12 @@
  */
 
 #include "examplewindow.h"
+#include <gtkmm/stock.h>
 #include <iostream>
 
 ExampleWindow::ExampleWindow()
-: m_Label("Right-click to see the popup menu.")
+: m_Label("Right-click to see the popup menu."),
+  m_Image(Gtk::Stock::DIALOG_QUESTION, Gtk::ICON_SIZE_MENU)
 {
   set_title("popup example");
   set_default_size(200, 200);
@@ -36,15 +38,22 @@ ExampleWindow::ExampleWindow()
 
   //Fill menu:
   {
-  	Gtk::Menu::MenuList& menulist = m_Menu_Popup.items();
+    Gtk::Menu::MenuList& menulist = m_Menu_Popup.items();
 
-  	menulist.push_back( Gtk::Menu_Helpers::MenuElem("_Edit",
+    menulist.push_back( Gtk::Menu_Helpers::MenuElem("_Edit",
       SigC::slot(*this, &ExampleWindow::on_menu_file_popup_generic) ) );
-	menulist.push_back( Gtk::Menu_Helpers::MenuElem("_Process", Gtk::Menu::AccelKey("<control>p"),
+    menulist.push_back( Gtk::Menu_Helpers::MenuElem("_Process", Gtk::Menu::AccelKey("<control>p"),
       SigC::slot(*this, &ExampleWindow::on_menu_file_popup_generic) ) );
-  	menulist.push_back( Gtk::Menu_Helpers::MenuElem("_Remove",
+    menulist.push_back( Gtk::Menu_Helpers::MenuElem("_Remove",
       SigC::slot(*this, &ExampleWindow::on_menu_file_popup_generic) ) );
+
+    //Add a ImageMenuElem:
+    menulist.push_back( Gtk::Menu_Helpers::ImageMenuElem("_Something", m_Image,
+      SigC::slot(*this, &ExampleWindow::on_menu_file_popup_generic) ) ) ;
+
+
   }
+  m_Menu_Popup.accelerate(*this);
 
   show_all_children();
 }
@@ -62,7 +71,7 @@ bool ExampleWindow::on_button_press_event(GdkEventButton* event)
 {
   if( (event->type == GDK_BUTTON_PRESS) && (event->button == 3) )
   {
-    m_Menu_Popup.popup(*this, event->button, event->time);
+    m_Menu_Popup.popup(event->button, event->time);
     return true; //It has been handled.
   }
   else
