@@ -35,7 +35,7 @@ Rulers::Rulers() :
   m_table.attach(m_area, 1,2,1,2,
 		 Gtk::EXPAND | Gtk::FILL , Gtk::FILL, 0, 0);
   
-  m_area.set_events(Gdk::POINTER_MOTION_MASK | Gdk::POINTER_MOTION_HINT_MASK );
+  m_area.set_events(Gdk::POINTER_MOTION_MASK | Gdk::BUTTON_PRESS_MASK );
 
   //Connect a signal handler for the DrawingArea's "motion_notify_event" signal, to detect cursor movement:
   m_area.signal_motion_notify_event().connect( SigC::slot(*this, &Rulers::on_area_motion_notify_event) );
@@ -78,7 +78,7 @@ int main (int argc, char *argv[])
 
   Rulers rulers;
 
-  myapp.run(rulers);
+  Gtk::Main::run(rulers);
   return 0;
 }
 
