@@ -23,11 +23,12 @@ protected:
 };
 
 
-StatusBarExample::StatusBarExample() :
+StatusBarExample::StatusBarExample()
+:
+  m_count(1),
   m_vbox(false, 1),
   m_bPush("push item"),
-  m_bPop("pop last item"),
-  m_count(1)
+  m_bPop("pop last item")
 {
   m_context_id = m_status_bar.get_context_id("Statusbar example");
 
