@@ -18,16 +18,16 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <gtk--.h>
-#include <gtk--/table.h>
-#include <gtk--/togglebutton.h>
+#include <gtkmm.h>
+#include <gtkmm/table.h>
+#include <gtkmm/togglebutton.h>
 #include "tictactoe.h"
 
 TicTacToe::TicTacToe ()
 {
   Gtk::Table *table;
   Gtk::ToggleButton *button;
-  gint i,j;
+  int i,j;
   
   table = manage( new Gtk::Table (3, 3, true) );
   add ( *table);
@@ -37,10 +37,10 @@ TicTacToe::TicTacToe ()
       {
 	buttons[i][j] = button = manage( new Gtk::ToggleButton ());
 	table-> attach (*button, i, i+1, j, j+1);
-	button-> toggled.connect ( bind(
-                                     slot(this, &TicTacToe::toggle), 
+	button-> signal_toggled().connect ( SigC::bind(
+                                     SigC::slot(*this, &TicTacToe::toggle), 
                                      button));
-	button-> set_usize (20, 20);
+	button-> set_size_request (20, 20);
       }
 
   table-> show_all();
