@@ -2,11 +2,9 @@
 #ifndef _GLIBMM_MAIN_H
 #define _GLIBMM_MAIN_H
 
-/* $Id: main.h,v 1.10 2002/04/23 10:43:22 daniel Exp $ */
+/* $Id: main.h,v 1.18 2002/12/01 19:24:12 daniel Exp $ */
 
-/* main.h
- *
- * Copyright (C) 2002 The gtkmm Development Team
+/* Copyright (C) 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -41,6 +39,7 @@ namespace Glib
 
 class Cond;
 class Mutex;
+class IOChannel;
 
 
 /** @defgroup MainLoop The Main Event Loop
@@ -84,12 +83,23 @@ enum
 };
 
 
-/** I/O condition flags, corresponding to those
- * used by the <tt>%poll()</tt> system call on UNIX.
+/** A bitwise combination representing an I/O condition to watch for on an
+ * event source.
+ * The flags correspond to those used by the <tt>%poll()</tt> system call
+ * on UNIX (see <tt>man 2 poll</tt>).  To test for individual flags, do
+ * something like this:
+ * @code
+ * if((condition & Glib::IO_OUT) != 0)
+ *   do_some_output();
+ * @endcode
  * @par Bitwise operators:
  * <tt>IOCondition operator|(IOCondition, IOCondition)</tt><br>
  * <tt>IOCondition operator&(IOCondition, IOCondition)</tt><br>
+ * <tt>IOCondition operator^(IOCondition, IOCondition)</tt><br>
  * <tt>IOCondition operator~(IOCondition)</tt><br>
+ * <tt>IOCondition& operator|=(IOCondition&, IOCondition)</tt><br>
+ * <tt>IOCondition& operator&=(IOCondition&, IOCondition)</tt><br>
+ * <tt>IOCondition& operator^=(IOCondition&, IOCondition)</tt><br>
  */
 enum IOCondition
 {
@@ -108,9 +118,21 @@ inline IOCondition operator|(IOCondition lhs, IOCondition rhs)
 inline IOCondition operator&(IOCondition lhs, IOCondition rhs)
   { return static_cast<IOCondition>(static_cast<unsigned>(lhs) & static_cast<unsigned>(rhs)); }
 
+inline IOCondition operator^(IOCondition lhs, IOCondition rhs)
+  { return static_cast<IOCondition>(static_cast<unsigned>(lhs) ^ static_cast<unsigned>(rhs)); }
+
 inline IOCondition operator~(IOCondition flags)
   { return static_cast<IOCondition>(~static_cast<unsigned>(flags)); }
 
+inline IOCondition& operator|=(IOCondition& lhs, IOCondition rhs)
+  { return (lhs = static_cast<IOCondition>(static_cast<unsigned>(lhs) | static_cast<unsigned>(rhs))); }
+
+inline IOCondition& operator&=(IOCondition& lhs, IOCondition rhs)
+  { return (lhs = static_cast<IOCondition>(static_cast<unsigned>(lhs) & static_cast<unsigned>(rhs))); }
+
+inline IOCondition& operator^=(IOCondition& lhs, IOCondition rhs)
+  { return (lhs = static_cast<IOCondition>(static_cast<unsigned>(lhs) ^ static_cast<unsigned>(rhs))); }
+
 
 class PollFD
 {
@@ -218,6 +240,7 @@ public:
    * @endcode
    * @param slot A slot to call when polling @a fd results in an event that matches @a condition.
    * The event will be passed as a parameter to @a slot.
+   * If @a io_handler returns <tt>false</tt> the signal is disconnected.
    * @param fd The file descriptor (or a @c HANDLE on Win32 systems) to watch.
    * @param condition The conditions to watch for.
    * @param priority The priority of the new event source.
@@ -226,6 +249,27 @@ public:
   SigC::Connection connect(const SigC::Slot1<bool,IOCondition>& slot, int fd,
                            IOCondition condition, int priority = PRIORITY_DEFAULT);
 
+  /** Connects an I/O channel.
+   * @code
+   * Glib::signal_io().connect(SigC::slot(&io_handler), channel, Glib::IO_IN | Glib::IO_HUP);
+   * @endcode
+   * is equivalent to:
+   * @code
+   * const Glib::RefPtr<Glib::IOSource> io_source = Glib::IOSource::create(channel, Glib::IO_IN | Glib::IO_HUP);
+   * io_source->connect(SigC::slot(&io_handler));
+   * io_source->attach(Glib::MainContext::get_default());
+   * @endcode
+   * @param slot A slot to call when polling @a fd results in an event that matches @a condition.
+   * The event will be passed as a parameter to @a slot.
+   * If @a io_handler returns <tt>false</tt> the signal is disconnected.
+   * @param channel The IOChannel object to watch.
+   * @param condition The conditions to watch for.
+   * @param priority The priority of the new event source.
+   * @return A connection handle, which can be used to disconnect the handler.
+   */
+  SigC::Connection connect(const SigC::Slot1<bool,IOCondition>& slot, const Glib::RefPtr<IOChannel>& channel,
+                           IOCondition condition, int priority = PRIORITY_DEFAULT);
+
 private:
   GMainContext* context_;
 
@@ -384,7 +428,19 @@ public:
   void unreference() const;
 
 protected:
+  /** Construct an object that uses the virtual functions prepare(), check() and dispatch().
+   */
   Source();
+
+  /** Wrap an existing GSource object and install the given callback function.
+   * The constructed object doesn't use the virtual functions prepare(), check() and dispatch().
+   * This ctor is for use by derived types that need to wrap a GSource object.
+   * The callback function can be a static member function. But beware!
+   * Depending on the actual implementation of the GSource's virtual functions
+   * the expected type of the callback function can differ from GSourceFunc.
+   */
+  Source(GSource* cast_item, GSourceFunc callback_func);
+
   virtual ~Source();
 
   SigC::Connection connect_generic(const SigC::SlotBase& slot);
@@ -403,12 +459,16 @@ private:
 
 #ifndef DOXGEN_SHOULD_SKIP_THIS
 
-  static GSourceFuncs vfunc_table_;
+  static inline Source* get_wrapper(GSource* source);
+
+  static const GSourceFuncs vfunc_table_;
 
   static gboolean prepare_vfunc(GSource* source, int* timeout);
   static gboolean check_vfunc(GSource* source);
   static gboolean dispatch_vfunc(GSource* source, GSourceFunc callback, void* user_data);
-  static void finalize_vfunc(GSource* source);
+public:
+  static void destroy_notify_callback(void* data);
+private:
 
 #endif /* DOXGEN_SHOULD_SKIP_THIS */
 
@@ -436,7 +496,7 @@ protected:
 
 private:
   Glib::TimeVal expiration_;
-  int           interval_;
+  unsigned int  interval_;
 };
 
 
@@ -464,10 +524,12 @@ public:
   typedef Glib::IOSource CppObjectType;
 
   static Glib::RefPtr<IOSource> create(int fd, IOCondition condition);
+  static Glib::RefPtr<IOSource> create(const Glib::RefPtr<IOChannel>& channel, IOCondition condition);
   SigC::Connection connect(const SigC::Slot1<bool,IOCondition>& slot);
 
 protected:
   IOSource(int fd, IOCondition condition);
+  IOSource(const Glib::RefPtr<IOChannel>& channel, IOCondition condition);
   virtual ~IOSource();
 
   virtual bool prepare(int& timeout);
